hierarch.resampling
===================

.. automodule:: hierarch.resampling

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
      :nosignatures:
   
      Bootstrapper
      Permuter
   
   

   
   
   



